Function fasten_mutate::mutate [−][src]
Mutate a str of a sequence of nucleotides using the nucleotides
in a vector nts.
This function does not use any kind of mutation model and will
choose random positions to replace with random nucleotides.